==> haskell-primitive-addr-0.1.0.2-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-99zUlmNiURM4eR00MMgNjM
key:                  primitive-addr-0.1.0.2-99zUlmNiURM4eR00MMgNjM
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  f2f428b3844fa3d27e4941410d99a48a
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-99zUlmNiURM4eR00MMgNjM
depends:
    base-4.17.2.1 primitive-0.8.0.0-7hRrrVot93LKTsSUGSTocq

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-addr-0.1.0.2-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-7zSYlZKFVxQJHM9Fvo00zL
key:                  primitive-addr-0.1.0.2-7zSYlZKFVxQJHM9Fvo00zL
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  67cd5e5bae0e5e93494996a1823845dc
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-7zSYlZKFVxQJHM9Fvo00zL
depends:
    base-4.17.2.1 primitive-0.8.0.0-7npiYBJB1rbGeYpNSKu2QX

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
